@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,6 +18,10 @@
  */
 package org.apache.parquet.avro;
 
+import static java.lang.Thread.sleep;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
+
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileReader;
@@ -39,29 +43,28 @@ import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import static java.lang.Thread.sleep;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
-
 public class TestInputOutputFormat {
   private static final Logger LOG = LoggerFactory.getLogger(TestInputOutputFormat.class);
 
   private static Schema avroSchema;
+
   static {
     avroSchema = Schema.createRecord("record1", null, null, false);
-    avroSchema.setFields(
-        Arrays.asList(new Schema.Field("a",
-            Schema.createUnion(Arrays.asList(Schema.create(Schema.Type.INT), Schema.create(Schema.Type.NULL))),
-            null, null)));
+    avroSchema.setFields(Arrays.asList(new Schema.Field(
+        "a",
+        Schema.createUnion(Arrays.asList(Schema.create(Schema.Type.INT), Schema.create(Schema.Type.NULL))),
+        null,
+        null)));
   }
 
   public static GenericRecord nextRecord(Integer i) {
     return new GenericRecordBuilder(avroSchema).set("a", i).build();
-  };
+  }
+  ;
 
   public static class MyMapper extends Mapper<LongWritable, Text, Void, GenericRecord> {
 
-    public void run(Context context) throws IOException ,InterruptedException {
+    public void run(Context context) throws IOException, InterruptedException {
       for (int i = 0; i < 10; i++) {
         GenericRecord a;
         a = TestInputOutputFormat.nextRecord(i == 4 ? null : i);
@@ -71,10 +74,9 @@ public class TestInputOutputFormat {
   }
 
   public static class MyMapper2 extends Mapper<Void, GenericRecord, LongWritable, Text> {
-    protected void map(Void key, GenericRecord value, Context context) throws IOException ,InterruptedException {
+    protected void map(Void key, GenericRecord value, Context context) throws IOException, InterruptedException {
       context.write(null, new Text(value.toString()));
     }
-
   }
 
   @Test
@@ -117,7 +119,8 @@ public class TestInputOutputFormat {
       waitForJob(job);
     }
 
-    try(final BufferedReader out = new BufferedReader(new FileReader(new File(outputPath.toString(), "part-m-00000")))) {
+    try (final BufferedReader out =
+        new BufferedReader(new FileReader(new File(outputPath.toString(), "part-m-00000")))) {
       String lineOut;
       int lineNumber = 0;
       while ((lineOut = out.readLine()) != null) {
@@ -141,5 +144,4 @@ public class TestInputOutputFormat {
       throw new RuntimeException("job failed " + job.getJobName());
     }
   }
-
 }
