@@ -18,13 +18,15 @@
  */
 package org.apache.parquet.cli;
 
+import com.beust.jcommander.DefaultUsageFormatter;
+import com.beust.jcommander.IUsageFormatter;
 import com.beust.jcommander.JCommander;
 import com.beust.jcommander.Parameter;
 import com.beust.jcommander.ParameterDescription;
 import com.beust.jcommander.Parameters;
 import com.google.common.collect.Lists;
-import org.slf4j.Logger;
 import java.util.List;
+import org.slf4j.Logger;
 
 @Parameters(commandDescription = "Retrieves details on the functions of other commands")
 public class Help implements Command {
@@ -33,11 +35,13 @@ public class Help implements Command {
 
   private final JCommander jc;
   private final Logger console;
+  private final IUsageFormatter formatter;
   private String programName;
 
   public Help(JCommander jc, Logger console) {
     this.jc = jc;
     this.console = console;
+    this.formatter = new DefaultUsageFormatter(jc);
   }
 
   public void setProgramName(String programName) {
@@ -48,7 +52,6 @@ public class Help implements Command {
   public int run() {
     if (helpCommands.isEmpty()) {
       printGenericHelp();
-
     } else {
       for (String cmd : helpCommands) {
         JCommander commander = jc.getCommands().get(cmd);
@@ -59,15 +62,16 @@ public class Help implements Command {
         }
 
         boolean hasRequired = false;
-        if (commander.getParameters().stream().anyMatch(p -> p.getNames().isEmpty())) {
-          console.info("\nUsage: {} [general options] {} {} [command options]",
-            new Object[] { programName, cmd, commander.getMainParameterDescription() });
+        if (commander.getParameters().stream()
+            .anyMatch(p -> p.getNames().isEmpty())) {
+          console.info(
+              "\nUsage: {} [general options] {} {} [command options]",
+              new Object[] {programName, cmd, commander.getMainParameterDescription()});
         } else {
-          console.info("\nUsage: {} [general options] {} [command options]",
-            new Object[] { programName, cmd });
+          console.info("\nUsage: {} [general options] {} [command options]", new Object[] {programName, cmd});
         }
         console.info("\n  Description:");
-        console.info("\n    {}", jc.getCommandDescription(cmd));
+        console.info("\n    {}", formatter.getCommandDescription(cmd));
         if (!commander.getParameters().isEmpty()) {
           console.info("\n  Command options:\n");
           for (ParameterDescription param : commander.getParameters()) {
@@ -85,8 +89,7 @@ public class Help implements Command {
               // comment
               console.info("\n    {}", example);
             } else {
-              console.info("    {} {} {}",
-                  new Object[] {programName, cmd, example});
+              console.info("    {} {} {}", new Object[] {programName, cmd, example});
             }
           }
         }
@@ -99,9 +102,7 @@ public class Help implements Command {
 
   public void printGenericHelp() {
     boolean hasRequired = false;
-    console.info(
-        "\nUsage: {} [options] [command] [command options]",
-        programName);
+    console.info("\nUsage: {} [options] [command] [command options]", programName);
     console.info("\n  Options:\n");
     for (ParameterDescription param : jc.getParameters()) {
       hasRequired = printOption(console, param) || hasRequired;
@@ -111,27 +112,27 @@ public class Help implements Command {
     }
     console.info("\n  Commands:\n");
     for (String command : jc.getCommands().keySet()) {
-      console.info("    {}\n\t{}",
-          command, jc.getCommandDescription(command));
+      console.info("    {}\n\t{}", command, formatter.getCommandDescription(command));
     }
 
-    jc.getCommands().keySet().stream().filter(s -> !s.equals("help")).findFirst().ifPresent(command -> {
-      console.info("\n  Examples:");
-      console.info("\n    # print information for {}\n    {} help {}",
-        command, programName, command);
-      console.info("\n  See '{} help <command>' for more information on a " +
-        "specific command.", programName);
-    });
+    jc.getCommands().keySet().stream()
+        .filter(s -> !s.equals("help"))
+        .findFirst()
+        .ifPresent(command -> {
+          console.info("\n  Examples:");
+          console.info("\n    # print information for {}\n    {} help {}", command, programName, command);
+          console.info(
+              "\n  See '{} help <command>' for more information on a " + "specific command.",
+              programName);
+        });
   }
 
   private boolean printOption(Logger console, ParameterDescription param) {
     boolean required = param.getParameter().required();
     if (!param.getParameter().hidden()) {
-      console.info("  {} {}\n\t{}{}", new Object[]{
-          required ? "*" : " ",
-          param.getNames().trim(),
-          param.getDescription(),
-          formatDefault(param)});
+      console.info("  {} {}\n\t{}{}", new Object[] {
+        required ? "*" : " ", param.getNames().trim(), param.getDescription(), formatDefault(param)
+      });
     }
     return required;
   }
@@ -141,9 +142,8 @@ public class Help implements Command {
     if (defaultValue == null || param.getParameter().arity() < 1) {
       return "";
     }
-    return " (default: " + ((defaultValue instanceof String) ?
-        "\"" + defaultValue + "\"" :
-        defaultValue.toString()) + ")";
+    return " (default: " + ((defaultValue instanceof String) ? "\"" + defaultValue + "\"" : defaultValue.toString())
+        + ")";
   }
 
   @Override
