@@ -19,23 +19,20 @@
 package org.apache.parquet.column.impl;
 
 import java.io.IOException;
-import java.util.OptionalLong;
-
+import java.util.Objects;
 import org.apache.parquet.column.ColumnDescriptor;
 import org.apache.parquet.column.ColumnWriter;
 import org.apache.parquet.column.ParquetProperties;
 import org.apache.parquet.column.page.DictionaryPage;
 import org.apache.parquet.column.page.PageWriter;
+import org.apache.parquet.column.statistics.SizeStatistics;
 import org.apache.parquet.column.statistics.Statistics;
 import org.apache.parquet.column.values.ValuesWriter;
-import org.apache.parquet.column.values.bloomfilter.BlockSplitBloomFilter;
-import org.apache.parquet.column.values.bloomfilter.BloomFilter;
 import org.apache.parquet.column.values.bloomfilter.BloomFilterWriter;
 import org.apache.parquet.io.ParquetEncodingException;
 import org.apache.parquet.io.api.Binary;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import org.apache.parquet.bytes.BytesInput;
 
 /**
  * Base implementation for {@link ColumnWriter} to be extended to specialize for V1 and V2 pages.
@@ -54,49 +51,33 @@ abstract class ColumnWriterBase implements ColumnWriter {
   private ValuesWriter dataColumn;
   private int valueCount;
 
-  private Statistics<?> statistics;
   private long rowsWrittenSoFar = 0;
   private int pageRowCount;
+  private StatusManager statusManager = StatusManager.create();
 
-  private final BloomFilterWriter bloomFilterWriter;
-  private final BloomFilter bloomFilter;
+  private final ColumnValueCollector collector;
 
-  ColumnWriterBase(
-      ColumnDescriptor path,
-      PageWriter pageWriter,
-      ParquetProperties props) {
+  ColumnWriterBase(ColumnDescriptor path, PageWriter pageWriter, ParquetProperties props) {
     this(path, pageWriter, null, props);
   }
 
   ColumnWriterBase(
-    ColumnDescriptor path,
-    PageWriter pageWriter,
-    BloomFilterWriter bloomFilterWriter,
-    ParquetProperties props
-  ) {
+      ColumnDescriptor path,
+      PageWriter pageWriter,
+      BloomFilterWriter bloomFilterWriter,
+      ParquetProperties props) {
     this.path = path;
     this.pageWriter = pageWriter;
-    resetStatistics();
 
     this.repetitionLevelColumn = createRLWriter(props, path);
     this.definitionLevelColumn = createDLWriter(props, path);
     this.dataColumn = props.newValuesWriter(path);
 
-    this.bloomFilterWriter = bloomFilterWriter;
-    if (bloomFilterWriter == null) {
-      this.bloomFilter = null;
-      return;
-    }
-    int maxBloomFilterSize = props.getMaxBloomFilterBytes();
+    this.collector = new ColumnValueCollector(path, bloomFilterWriter, props);
+  }
 
-    OptionalLong ndv = props.getBloomFilterNDV(path);
-    // If user specify the column NDV, we construct Bloom filter from it.
-    if (ndv.isPresent()) {
-      int optimalNumOfBits = BlockSplitBloomFilter.optimalNumOfBits(ndv.getAsLong(), BlockSplitBloomFilter.DEFAULT_FPP);
-      this.bloomFilter = new BlockSplitBloomFilter(optimalNumOfBits / 8, maxBloomFilterSize);
-    } else {
-      this.bloomFilter = new BlockSplitBloomFilter(maxBloomFilterSize);
-    }
+  void initStatusManager(StatusManager statusManager) {
+    this.statusManager = Objects.requireNonNull(statusManager);
   }
 
   abstract ValuesWriter createRLWriter(ParquetProperties props, ColumnDescriptor path);
@@ -107,10 +88,6 @@ abstract class ColumnWriterBase implements ColumnWriter {
     LOG.debug("{} {} r:{} d:{}", path, value, r, d);
   }
 
-  private void resetStatistics() {
-    this.statistics = Statistics.createStats(path.getPrimitiveType());
-  }
-
   private void definitionLevel(int definitionLevel) {
     definitionLevelColumn.writeInteger(definitionLevel);
   }
@@ -131,12 +108,16 @@ abstract class ColumnWriterBase implements ColumnWriter {
    */
   @Override
   public void writeNull(int repetitionLevel, int definitionLevel) {
-    if (DEBUG)
-      log(null, repetitionLevel, definitionLevel);
-    repetitionLevel(repetitionLevel);
-    definitionLevel(definitionLevel);
-    statistics.incrementNumNulls();
-    ++valueCount;
+    if (DEBUG) log(null, repetitionLevel, definitionLevel);
+    try {
+      repetitionLevel(repetitionLevel);
+      definitionLevel(definitionLevel);
+      collector.writeNull(repetitionLevel, definitionLevel);
+      ++valueCount;
+    } catch (Throwable e) {
+      statusManager.abort();
+      throw e;
+    }
   }
 
   @Override
@@ -155,36 +136,6 @@ abstract class ColumnWriterBase implements ColumnWriter {
         + pageWriter.getMemSize();
   }
 
-  private void updateBloomFilter(int value) {
-    if (bloomFilter != null) {
-      bloomFilter.insertHash(bloomFilter.hash(value));
-    }
-  }
-
-  private void updateBloomFilter(long value) {
-    if (bloomFilter != null) {
-      bloomFilter.insertHash(bloomFilter.hash(value));
-    }
-  }
-
-  private void updateBloomFilter(double value) {
-    if (bloomFilter != null) {
-      bloomFilter.insertHash(bloomFilter.hash(value));
-    }
-  }
-
-  private void updateBloomFilter(float value) {
-    if (bloomFilter != null) {
-      bloomFilter.insertHash(bloomFilter.hash(value));
-    }
-  }
-
-  private void updateBloomFilter(Binary value) {
-    if (bloomFilter != null) {
-      bloomFilter.insertHash(bloomFilter.hash(value));
-    }
-  }
-
   /**
    * Writes the current value
    *
@@ -194,14 +145,17 @@ abstract class ColumnWriterBase implements ColumnWriter {
    */
   @Override
   public void write(double value, int repetitionLevel, int definitionLevel) {
-    if (DEBUG)
-      log(value, repetitionLevel, definitionLevel);
-    repetitionLevel(repetitionLevel);
-    definitionLevel(definitionLevel);
-    dataColumn.writeDouble(value);
-    statistics.updateStats(value);
-    updateBloomFilter(value);
-    ++valueCount;
+    if (DEBUG) log(value, repetitionLevel, definitionLevel);
+    try {
+      repetitionLevel(repetitionLevel);
+      definitionLevel(definitionLevel);
+      dataColumn.writeDouble(value);
+      collector.write(value, repetitionLevel, definitionLevel);
+      ++valueCount;
+    } catch (Throwable e) {
+      statusManager.abort();
+      throw e;
+    }
   }
 
   /**
@@ -213,14 +167,17 @@ abstract class ColumnWriterBase implements ColumnWriter {
    */
   @Override
   public void write(float value, int repetitionLevel, int definitionLevel) {
-    if (DEBUG)
-      log(value, repetitionLevel, definitionLevel);
-    repetitionLevel(repetitionLevel);
-    definitionLevel(definitionLevel);
-    dataColumn.writeFloat(value);
-    statistics.updateStats(value);
-    updateBloomFilter(value);
-    ++valueCount;
+    if (DEBUG) log(value, repetitionLevel, definitionLevel);
+    try {
+      repetitionLevel(repetitionLevel);
+      definitionLevel(definitionLevel);
+      dataColumn.writeFloat(value);
+      collector.write(value, repetitionLevel, definitionLevel);
+      ++valueCount;
+    } catch (Throwable e) {
+      statusManager.abort();
+      throw e;
+    }
   }
 
   /**
@@ -232,14 +189,17 @@ abstract class ColumnWriterBase implements ColumnWriter {
    */
   @Override
   public void write(Binary value, int repetitionLevel, int definitionLevel) {
-    if (DEBUG)
-      log(value, repetitionLevel, definitionLevel);
-    repetitionLevel(repetitionLevel);
-    definitionLevel(definitionLevel);
-    dataColumn.writeBytes(value);
-    statistics.updateStats(value);
-    updateBloomFilter(value);
-    ++valueCount;
+    if (DEBUG) log(value, repetitionLevel, definitionLevel);
+    try {
+      repetitionLevel(repetitionLevel);
+      definitionLevel(definitionLevel);
+      dataColumn.writeBytes(value);
+      collector.write(value, repetitionLevel, definitionLevel);
+      ++valueCount;
+    } catch (Throwable e) {
+      statusManager.abort();
+      throw e;
+    }
   }
 
   /**
@@ -251,13 +211,17 @@ abstract class ColumnWriterBase implements ColumnWriter {
    */
   @Override
   public void write(boolean value, int repetitionLevel, int definitionLevel) {
-    if (DEBUG)
-      log(value, repetitionLevel, definitionLevel);
-    repetitionLevel(repetitionLevel);
-    definitionLevel(definitionLevel);
-    dataColumn.writeBoolean(value);
-    statistics.updateStats(value);
-    ++valueCount;
+    if (DEBUG) log(value, repetitionLevel, definitionLevel);
+    try {
+      repetitionLevel(repetitionLevel);
+      definitionLevel(definitionLevel);
+      dataColumn.writeBoolean(value);
+      collector.write(value, repetitionLevel, definitionLevel);
+      ++valueCount;
+    } catch (Throwable e) {
+      statusManager.abort();
+      throw e;
+    }
   }
 
   /**
@@ -269,14 +233,17 @@ abstract class ColumnWriterBase implements ColumnWriter {
    */
   @Override
   public void write(int value, int repetitionLevel, int definitionLevel) {
-    if (DEBUG)
-      log(value, repetitionLevel, definitionLevel);
-    repetitionLevel(repetitionLevel);
-    definitionLevel(definitionLevel);
-    dataColumn.writeInteger(value);
-    statistics.updateStats(value);
-    updateBloomFilter(value);
-    ++valueCount;
+    if (DEBUG) log(value, repetitionLevel, definitionLevel);
+    try {
+      repetitionLevel(repetitionLevel);
+      definitionLevel(definitionLevel);
+      dataColumn.writeInteger(value);
+      collector.write(value, repetitionLevel, definitionLevel);
+      ++valueCount;
+    } catch (Throwable e) {
+      statusManager.abort();
+      throw e;
+    }
   }
 
   /**
@@ -288,14 +255,17 @@ abstract class ColumnWriterBase implements ColumnWriter {
    */
   @Override
   public void write(long value, int repetitionLevel, int definitionLevel) {
-    if (DEBUG)
-      log(value, repetitionLevel, definitionLevel);
-    repetitionLevel(repetitionLevel);
-    definitionLevel(definitionLevel);
-    dataColumn.writeLong(value);
-    statistics.updateStats(value);
-    updateBloomFilter(value);
-    ++valueCount;
+    if (DEBUG) log(value, repetitionLevel, definitionLevel);
+    try {
+      repetitionLevel(repetitionLevel);
+      definitionLevel(definitionLevel);
+      dataColumn.writeLong(value);
+      collector.write(value, repetitionLevel, definitionLevel);
+      ++valueCount;
+    } catch (Throwable e) {
+      statusManager.abort();
+      throw e;
+    }
   }
 
   /**
@@ -303,20 +273,26 @@ abstract class ColumnWriterBase implements ColumnWriter {
    * Is called right after writePage
    */
   void finalizeColumnChunk() {
-    final DictionaryPage dictionaryPage = dataColumn.toDictPageAndClose();
-    if (dictionaryPage != null) {
-      if (DEBUG)
-        LOG.debug("write dictionary");
-      try {
-        pageWriter.writeDictionaryPage(dictionaryPage);
-      } catch (IOException e) {
-        throw new ParquetEncodingException("could not write dictionary page for " + path, e);
-      }
-      dataColumn.resetDictionary();
+    if (statusManager.isAborted()) {
+      // We are aborting -> nothing to be done
+      return;
     }
+    try {
+      final DictionaryPage dictionaryPage = dataColumn.toDictPageAndClose();
+      if (dictionaryPage != null) {
+        if (DEBUG) LOG.debug("write dictionary");
+        try {
+          pageWriter.writeDictionaryPage(dictionaryPage);
+        } catch (IOException e) {
+          throw new ParquetEncodingException("could not write dictionary page for " + path, e);
+        }
+        dataColumn.resetDictionary();
+      }
 
-    if (bloomFilterWriter != null && bloomFilter != null) {
-      bloomFilterWriter.writeBloomFilter(bloomFilter);
+      collector.finalizeColumnChunk();
+    } catch (Throwable t) {
+      statusManager.abort();
+      throw t;
     }
   }
 
@@ -354,17 +330,24 @@ abstract class ColumnWriterBase implements ColumnWriter {
   }
 
   /**
-   * @param indent
-   *          a prefix to format lines
+   * @param indent a prefix to format lines
    * @return a formatted string showing how memory is used
    */
   String memUsageString(String indent) {
     StringBuilder b = new StringBuilder(indent).append(path).append(" {\n");
-    b.append(indent).append(" r:").append(repetitionLevelColumn.getAllocatedSize()).append(" bytes\n");
-    b.append(indent).append(" d:").append(definitionLevelColumn.getAllocatedSize()).append(" bytes\n");
+    b.append(indent)
+        .append(" r:")
+        .append(repetitionLevelColumn.getAllocatedSize())
+        .append(" bytes\n");
+    b.append(indent)
+        .append(" d:")
+        .append(definitionLevelColumn.getAllocatedSize())
+        .append(" bytes\n");
     b.append(dataColumn.memUsageString(indent + "  data:")).append("\n");
     b.append(pageWriter.memUsageString(indent + "  pages:")).append("\n");
-    b.append(indent).append(String.format("  total: %,d/%,d", getTotalBufferedSize(), allocatedSize())).append("\n");
+    b.append(indent)
+        .append(String.format("  total: %,d/%,d", getTotalBufferedSize(), allocatedSize()))
+        .append("\n");
     b.append(indent).append("}\n");
     return b.toString();
   }
@@ -373,6 +356,10 @@ abstract class ColumnWriterBase implements ColumnWriter {
     return this.rowsWrittenSoFar;
   }
 
+  int getValueCount() {
+    return this.valueCount;
+  }
+
   /**
    * Writes the current data to a new page in the page store
    */
@@ -380,22 +367,44 @@ abstract class ColumnWriterBase implements ColumnWriter {
     if (valueCount == 0) {
       throw new ParquetEncodingException("writing empty page");
     }
-    this.rowsWrittenSoFar += pageRowCount;
-    if (DEBUG)
-      LOG.debug("write page");
+    if (statusManager.isAborted()) {
+      // We are aborting -> nothing to be done
+      return;
+    }
     try {
-      writePage(pageRowCount, valueCount, statistics, repetitionLevelColumn, definitionLevelColumn, dataColumn);
-    } catch (IOException e) {
-      throw new ParquetEncodingException("could not write page for " + path, e);
+      this.rowsWrittenSoFar += pageRowCount;
+      if (DEBUG) LOG.debug("write page");
+      try {
+        writePage(
+            pageRowCount,
+            valueCount,
+            collector.getStatistics(),
+            collector.getSizeStatistics(),
+            repetitionLevelColumn,
+            definitionLevelColumn,
+            dataColumn);
+      } catch (IOException e) {
+        throw new ParquetEncodingException("could not write page for " + path, e);
+      }
+      repetitionLevelColumn.reset();
+      definitionLevelColumn.reset();
+      dataColumn.reset();
+      valueCount = 0;
+      collector.resetPageStatistics();
+      pageRowCount = 0;
+    } catch (Throwable t) {
+      statusManager.abort();
+      throw t;
     }
-    repetitionLevelColumn.reset();
-    definitionLevelColumn.reset();
-    dataColumn.reset();
-    valueCount = 0;
-    resetStatistics();
-    pageRowCount = 0;
   }
 
-  abstract void writePage(int rowCount, int valueCount, Statistics<?> statistics, ValuesWriter repetitionLevels,
-      ValuesWriter definitionLevels, ValuesWriter values) throws IOException;
+  abstract void writePage(
+      int rowCount,
+      int valueCount,
+      Statistics<?> statistics,
+      SizeStatistics sizeStatistics,
+      ValuesWriter repetitionLevels,
+      ValuesWriter definitionLevels,
+      ValuesWriter values)
+      throws IOException;
 }
