@@ -18,6 +18,8 @@
  */
 package org.apache.parquet.internal.column.columnindex;
 
+import it.unimi.dsi.fastutil.ints.IntArrayList;
+import it.unimi.dsi.fastutil.ints.IntList;
 import java.nio.ByteBuffer;
 import java.util.Collections;
 import java.util.Iterator;
@@ -25,7 +27,6 @@ import java.util.PrimitiveIterator;
 import java.util.Random;
 import java.util.function.Function;
 import java.util.stream.IntStream;
-
 import org.apache.parquet.column.statistics.Statistics;
 import org.apache.parquet.internal.column.columnindex.ColumnIndexBuilder.ColumnIndexBase;
 import org.apache.parquet.schema.PrimitiveType;
@@ -36,9 +37,6 @@ import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import it.unimi.dsi.fastutil.ints.IntArrayList;
-import it.unimi.dsi.fastutil.ints.IntList;
-
 /**
  * Tests the operator implementations in {@link BoundaryOrder}.
  */
@@ -125,7 +123,8 @@ public class TestBoundaryOrder {
     private int binaryCompareCount;
     private int execCount;
 
-    IntList measureLinear(Function<ColumnIndexBase<?>.ValueComparator, PrimitiveIterator.OfInt> op,
+    IntList measureLinear(
+        Function<ColumnIndexBase<?>.ValueComparator, PrimitiveIterator.OfInt> op,
         ColumnIndexBase<?>.ValueComparator comparator) {
       IntList list = new IntArrayList(comparator.arrayLength());
       SpyValueComparatorBuilder.SpyValueComparator spyComparator = SPY_COMPARATOR_BUILDER.build(comparator);
@@ -136,7 +135,8 @@ public class TestBoundaryOrder {
       return list;
     }
 
-    IntList measureBinary(Function<ColumnIndexBase<?>.ValueComparator, PrimitiveIterator.OfInt> op,
+    IntList measureBinary(
+        Function<ColumnIndexBase<?>.ValueComparator, PrimitiveIterator.OfInt> op,
         ColumnIndexBase<?>.ValueComparator comparator) {
       IntList list = new IntArrayList(comparator.arrayLength());
       SpyValueComparatorBuilder.SpyValueComparator spyComparator = SPY_COMPARATOR_BUILDER.build(comparator);
@@ -162,14 +162,21 @@ public class TestBoundaryOrder {
       return String.format(
           "Linear search: %.2fms (avg: %.6fms); number of compares: %d (avg: %d) [100.00%%]%n"
               + "Binary search: %.2fms (avg: %.6fms); number of compares: %d (avg: %d) [%.2f%%]",
-          linearMs, linearMs / execCount, linearCompareCount, linearCompareCount / execCount,
-          binaryMs, binaryMs / execCount, binaryCompareCount, binaryCompareCount / execCount,
+          linearMs,
+          linearMs / execCount,
+          linearCompareCount,
+          linearCompareCount / execCount,
+          binaryMs,
+          binaryMs / execCount,
+          binaryCompareCount,
+          binaryCompareCount / execCount,
           100.0 * binaryCompareCount / linearCompareCount);
     }
   }
 
   private static final Logger LOGGER = LoggerFactory.getLogger(TestBoundaryOrder.class);
-  private static final PrimitiveType TYPE = Types.required(PrimitiveTypeName.INT32).named("test_int32");
+  private static final PrimitiveType TYPE =
+      Types.required(PrimitiveTypeName.INT32).named("test_int32");
   private static final int FROM = -15;
   private static final int TO = 15;
   private static final ColumnIndexBase<?> ASCENDING;
@@ -185,6 +192,7 @@ public class TestBoundaryOrder {
   private static final ColumnIndexBase<?> RAND_DESCENDING;
   private static final ColumnIndexBase<?> ALL_NULL_PAGES;
   private static final SpyValueComparatorBuilder SPY_COMPARATOR_BUILDER = new SpyValueComparatorBuilder();
+
   static {
     ColumnIndexBuilder builder = ColumnIndexBuilder.getBuilder(TYPE, Integer.MAX_VALUE);
     builder.add(stats(FROM, -12));
@@ -222,15 +230,21 @@ public class TestBoundaryOrder {
 
     builder = ColumnIndexBuilder.getBuilder(TYPE, Integer.MAX_VALUE);
     for (PrimitiveIterator.OfInt it = IntStream.generate(() -> RANDOM.nextInt(RAND_TO - RAND_FROM + 1) + RAND_FROM)
-        .limit(RAND_COUNT * 2).sorted().iterator(); it.hasNext();) {
+            .limit(RAND_COUNT * 2)
+            .sorted()
+            .iterator();
+        it.hasNext(); ) {
       builder.add(stats(it.nextInt(), it.nextInt()));
     }
     RAND_ASCENDING = (ColumnIndexBase<?>) builder.build();
 
     builder = ColumnIndexBuilder.getBuilder(TYPE, Integer.MAX_VALUE);
     for (Iterator<Integer> it = IntStream.generate(() -> RANDOM.nextInt(RAND_TO - RAND_FROM + 1) + RAND_FROM)
-        .limit(RAND_COUNT * 2).mapToObj(Integer::valueOf).sorted(Collections.reverseOrder()).iterator(); it
-            .hasNext();) {
+            .limit(RAND_COUNT * 2)
+            .mapToObj(Integer::valueOf)
+            .sorted(Collections.reverseOrder())
+            .iterator();
+        it.hasNext(); ) {
       builder.add(stats(it.next(), it.next()));
     }
     RAND_DESCENDING = (ColumnIndexBase<?>) builder.build();
@@ -250,7 +264,8 @@ public class TestBoundaryOrder {
     return stats;
   }
 
-  private static ExecStats validateOperator(String msg,
+  private static ExecStats validateOperator(
+      String msg,
       Function<ColumnIndexBase<?>.ValueComparator, PrimitiveIterator.OfInt> validatorOp,
       Function<ColumnIndexBase<?>.ValueComparator, PrimitiveIterator.OfInt> actualOp,
       ColumnIndexBase<?>.ValueComparator comparator) {
@@ -267,277 +282,342 @@ public class TestBoundaryOrder {
   @Test
   public void testEq() {
     for (int i = FROM - 1; i <= TO + 1; ++i) {
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::eq,
           BoundaryOrder.ASCENDING::eq,
           ASCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::eq,
           BoundaryOrder.DESCENDING::eq,
           DESCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
           BoundaryOrder.UNORDERED::eq,
           BoundaryOrder.ASCENDING::eq,
           ALL_NULL_PAGES.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
           BoundaryOrder.UNORDERED::eq,
           BoundaryOrder.DESCENDING::eq,
           ALL_NULL_PAGES.createValueComparator(i));
     }
     for (int i = SINGLE_FROM - 1; i <= SINGLE_TO + 1; ++i) {
       ColumnIndexBase<?>.ValueComparator singleComparator = SINGLE.createValueComparator(i);
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::eq,
           BoundaryOrder.ASCENDING::eq,
           singleComparator);
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::eq,
           BoundaryOrder.DESCENDING::eq,
           singleComparator);
     }
     ExecStats stats = new ExecStats();
     for (int i = RAND_FROM - 1; i <= RAND_TO + 1; ++i) {
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::eq,
           BoundaryOrder.ASCENDING::eq,
           RAND_ASCENDING.createValueComparator(i)));
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::eq,
           BoundaryOrder.DESCENDING::eq,
           RAND_DESCENDING.createValueComparator(i)));
     }
-    LOGGER.info("Executed eq on random data (page count: {}, values searched: {}):\n{}", RAND_COUNT,
-        RAND_TO - RAND_FROM + 2, stats);
+    LOGGER.info(
+        "Executed eq on random data (page count: {}, values searched: {}):\n{}",
+        RAND_COUNT,
+        RAND_TO - RAND_FROM + 2,
+        stats);
   }
 
   @Test
   public void testGt() {
     for (int i = FROM - 1; i <= TO + 1; ++i) {
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::gt,
           BoundaryOrder.ASCENDING::gt,
           ASCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::gt,
           BoundaryOrder.DESCENDING::gt,
           DESCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
           BoundaryOrder.UNORDERED::gt,
           BoundaryOrder.ASCENDING::gt,
           ALL_NULL_PAGES.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
           BoundaryOrder.UNORDERED::gt,
           BoundaryOrder.DESCENDING::gt,
           ALL_NULL_PAGES.createValueComparator(i));
     }
     for (int i = SINGLE_FROM - 1; i <= SINGLE_TO + 1; ++i) {
       ColumnIndexBase<?>.ValueComparator singleComparator = SINGLE.createValueComparator(i);
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::gt,
           BoundaryOrder.ASCENDING::gt,
           singleComparator);
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::gt,
           BoundaryOrder.DESCENDING::gt,
           singleComparator);
     }
     ExecStats stats = new ExecStats();
     for (int i = RAND_FROM - 1; i <= RAND_TO + 1; ++i) {
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::gt,
           BoundaryOrder.ASCENDING::gt,
           RAND_ASCENDING.createValueComparator(i)));
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::gt,
           BoundaryOrder.DESCENDING::gt,
           RAND_DESCENDING.createValueComparator(i)));
     }
-    LOGGER.info("Executed gt on random data (page count: {}, values searched: {}):\n{}", RAND_COUNT,
-        RAND_TO - RAND_FROM + 2, stats);
+    LOGGER.info(
+        "Executed gt on random data (page count: {}, values searched: {}):\n{}",
+        RAND_COUNT,
+        RAND_TO - RAND_FROM + 2,
+        stats);
   }
 
   @Test
   public void testGtEq() {
     for (int i = FROM - 1; i <= TO + 1; ++i) {
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::gtEq,
           BoundaryOrder.ASCENDING::gtEq,
           ASCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::gtEq,
           BoundaryOrder.DESCENDING::gtEq,
           DESCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
           BoundaryOrder.UNORDERED::gtEq,
           BoundaryOrder.ASCENDING::gtEq,
           ALL_NULL_PAGES.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
           BoundaryOrder.UNORDERED::gtEq,
           BoundaryOrder.DESCENDING::gtEq,
           ALL_NULL_PAGES.createValueComparator(i));
     }
     for (int i = SINGLE_FROM - 1; i <= SINGLE_TO + 1; ++i) {
       ColumnIndexBase<?>.ValueComparator singleComparator = SINGLE.createValueComparator(i);
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::gtEq,
           BoundaryOrder.ASCENDING::gtEq,
           singleComparator);
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::gtEq,
           BoundaryOrder.DESCENDING::gtEq,
           singleComparator);
     }
     ExecStats stats = new ExecStats();
     for (int i = RAND_FROM - 1; i <= RAND_TO + 1; ++i) {
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::gtEq,
           BoundaryOrder.ASCENDING::gtEq,
           RAND_ASCENDING.createValueComparator(i)));
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::gtEq,
           BoundaryOrder.DESCENDING::gtEq,
           RAND_DESCENDING.createValueComparator(i)));
     }
-    LOGGER.info("Executed gtEq on random data (page count: {}, values searched: {}):\n{}", RAND_COUNT,
-        RAND_TO - RAND_FROM + 2, stats);
+    LOGGER.info(
+        "Executed gtEq on random data (page count: {}, values searched: {}):\n{}",
+        RAND_COUNT,
+        RAND_TO - RAND_FROM + 2,
+        stats);
   }
 
   @Test
   public void testLt() {
     for (int i = FROM - 1; i <= TO + 1; ++i) {
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::lt,
           BoundaryOrder.ASCENDING::lt,
           ASCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::lt,
           BoundaryOrder.DESCENDING::lt,
           DESCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
           BoundaryOrder.UNORDERED::lt,
           BoundaryOrder.ASCENDING::lt,
           ALL_NULL_PAGES.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
           BoundaryOrder.UNORDERED::lt,
           BoundaryOrder.DESCENDING::lt,
           ALL_NULL_PAGES.createValueComparator(i));
     }
     for (int i = SINGLE_FROM - 1; i <= SINGLE_TO + 1; ++i) {
       ColumnIndexBase<?>.ValueComparator singleComparator = SINGLE.createValueComparator(i);
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::lt,
           BoundaryOrder.ASCENDING::lt,
           singleComparator);
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::lt,
           BoundaryOrder.DESCENDING::lt,
           singleComparator);
     }
     ExecStats stats = new ExecStats();
     for (int i = RAND_FROM - 1; i <= RAND_TO + 1; ++i) {
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::lt,
           BoundaryOrder.ASCENDING::lt,
           RAND_ASCENDING.createValueComparator(i)));
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::lt,
           BoundaryOrder.DESCENDING::lt,
           RAND_DESCENDING.createValueComparator(i)));
     }
-    LOGGER.info("Executed lt on random data (page count: {}, values searched: {}):\n{}", RAND_COUNT,
-        RAND_TO - RAND_FROM + 2, stats);
+    LOGGER.info(
+        "Executed lt on random data (page count: {}, values searched: {}):\n{}",
+        RAND_COUNT,
+        RAND_TO - RAND_FROM + 2,
+        stats);
   }
 
   @Test
   public void testLtEq() {
     for (int i = FROM - 1; i <= TO + 1; ++i) {
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::ltEq,
           BoundaryOrder.ASCENDING::ltEq,
           ASCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::ltEq,
           BoundaryOrder.DESCENDING::ltEq,
           DESCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
           BoundaryOrder.UNORDERED::ltEq,
           BoundaryOrder.ASCENDING::ltEq,
           ALL_NULL_PAGES.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
           BoundaryOrder.UNORDERED::ltEq,
           BoundaryOrder.DESCENDING::ltEq,
           ALL_NULL_PAGES.createValueComparator(i));
     }
     for (int i = SINGLE_FROM - 1; i <= SINGLE_TO + 1; ++i) {
       ColumnIndexBase<?>.ValueComparator singleComparator = SINGLE.createValueComparator(i);
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::ltEq,
           BoundaryOrder.ASCENDING::ltEq,
           singleComparator);
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::ltEq,
           BoundaryOrder.DESCENDING::ltEq,
           singleComparator);
     }
     ExecStats stats = new ExecStats();
     for (int i = RAND_FROM - 1; i <= RAND_TO + 1; ++i) {
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::ltEq,
           BoundaryOrder.ASCENDING::ltEq,
           RAND_ASCENDING.createValueComparator(i)));
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::ltEq,
           BoundaryOrder.DESCENDING::ltEq,
           RAND_DESCENDING.createValueComparator(i)));
     }
-    LOGGER.info("Executed ltEq on random data (page count: {}, values searched: {}):\n{}", RAND_COUNT,
-        RAND_TO - RAND_FROM + 2, stats);
+    LOGGER.info(
+        "Executed ltEq on random data (page count: {}, values searched: {}):\n{}",
+        RAND_COUNT,
+        RAND_TO - RAND_FROM + 2,
+        stats);
   }
 
   @Test
   public void testNotEq() {
     for (int i = -16; i <= 16; ++i) {
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::notEq,
           BoundaryOrder.ASCENDING::notEq,
           ASCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::notEq,
           BoundaryOrder.DESCENDING::notEq,
           DESCENDING.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with ASCENDING order in ",
           BoundaryOrder.UNORDERED::notEq,
           BoundaryOrder.ASCENDING::notEq,
           ALL_NULL_PAGES.createValueComparator(i));
-      validateOperator("Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
+      validateOperator(
+          "Mismatching page indexes for all null pages and value " + i + " with DESCENDING order in ",
           BoundaryOrder.UNORDERED::notEq,
           BoundaryOrder.DESCENDING::notEq,
           ALL_NULL_PAGES.createValueComparator(i));
     }
     for (int i = FROM - 1; i <= TO + 1; ++i) {
       ColumnIndexBase<?>.ValueComparator singleComparator = SINGLE.createValueComparator(i);
-      validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::notEq,
           BoundaryOrder.ASCENDING::notEq,
           singleComparator);
-      validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::notEq,
           BoundaryOrder.DESCENDING::notEq,
           singleComparator);
     }
     ExecStats stats = new ExecStats();
     for (int i = RAND_FROM - 1; i <= RAND_TO + 1; ++i) {
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with ASCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with ASCENDING order",
           BoundaryOrder.UNORDERED::notEq,
           BoundaryOrder.ASCENDING::notEq,
           RAND_ASCENDING.createValueComparator(i)));
-      stats.add(validateOperator("Mismatching page indexes for value " + i + " with DESCENDING order",
+      stats.add(validateOperator(
+          "Mismatching page indexes for value " + i + " with DESCENDING order",
           BoundaryOrder.UNORDERED::notEq,
           BoundaryOrder.DESCENDING::notEq,
           RAND_DESCENDING.createValueComparator(i)));
     }
-    LOGGER.info("Executed notEq on random data (page count: {}, values searched: {}):\n{}", RAND_COUNT,
-        RAND_TO - RAND_FROM + 2, stats);
+    LOGGER.info(
+        "Executed notEq on random data (page count: {}, values searched: {}):\n{}",
+        RAND_COUNT,
+        RAND_TO - RAND_FROM + 2,
+        stats);
   }
-
 }
